@@ -1,5 +1,5 @@
 package HackaMol::Molecule;
-$HackaMol::Molecule::VERSION = '0.031';
+$HackaMol::Molecule::VERSION = '0.032';
 #ABSTRACT: Molecule class for HackaMol
 use 5.008;
 use Moose;
@@ -64,7 +64,7 @@ sub charge {
   }
   if (@_){
     my $new_q = shift;
-    $self->set_charges($new_q);
+    $self->set_charges($t,$new_q);
   }
   return $q;
 }
@@ -245,7 +245,7 @@ HackaMol::Molecule - Molecule class for HackaMol
 
 =head1 VERSION
 
-version 0.031
+version 0.032
 
 =head1 SYNOPSIS
 
